version 10.0 
log using "C:\Documents and Settings\Matthew Golder\My Documents\publications\ajps2\final_version\replication\results_manytoone.log", replace
#delimit ;

*     ****************************************************************  *;
*     ***************************************************************** *;
*       File-Name:      results_manytoone.do                            *;
*       Date:           January 16, 2009                                *;
*       Author:         MG                                              *;
*       Purpose:        Replication results for many-to-one congruence  *;
*                       for AJPS 2010 article.                          *;
*       Input File:     final5.dta                                      *;
*       Output File:    results_manytoone.log                           *;
*       Data Output:    none                                            *;
*       Previous file:  final5.dta                                      *;
*       Machine:        office                                          *;
*     ****************************************************************  *;
*     ****************************************************************  *;

set mem 80m;

use "C:\Documents and Settings\Matthew Golder\My Documents\publications\ajps2\final_version\replication\final.dta", clear;

set more off;

desc;

sum;

*     ****************************************************************  *;
*       Results for Table 1.                                            *;
*     ****************************************************************  *;

ttest mv_gov40, by(majoritarian);
ttest voters_gov40, by(majoritarian); 
ttest relative_congruence40, by(majoritarian);

*     ****************************************************************  *;
*       Robustness checks for Table 1. Results do not depend on whether *;
*       we use all citizens or just the top 40% to estimate party       *;
*       positions.                                                      *;
*     ****************************************************************  *;

ttest mv_gov, by(majoritarian);
ttest voters_gov, by(majoritarian);
ttest relative_congruence, by(majoritarian);

*     ****************************************************************  *;
*       Robustness checks for Table 1. Results do not depend on whether *;
*       we use Achen's measure of relative congruence.                  *;
*     ****************************************************************  *;

ttest congruence40_achen, by(majoritarian);
ttest congruence_achen, by(majoritarian);


*     ****************************************************************  *;
*       Is voter dispersion different across democracy types?           *;
*     ****************************************************************  *;

ttest sd_voter, by(majoritarian);

*     ****************************************************************  *;
*       2 tailed test at 90% shows more dispersion in PR systems, one   *;
*       tailed test this is >95%.                                       *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Results for Table 2.                                            *;
*     ****************************************************************  *;

regress mv_gov40 disproportionality, robust cluster(countrycode);
regress voters_gov40 disproportionality, robust cluster(countrycode);
regress relative_congruence40 disproportionality, robust cluster(countrycode);

*     ****************************************************************  *;
*       Coefficient is always negative, indicating that majoritarian    *;
*       democracies have greater congruence.  However, none of the      *;
*       coefficients are significant.                                   *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Robustness checks for Table 2. Results do not depend on whether *;
*       we use robust and clustered standard errors or not.             *;
*     ****************************************************************  *; 

regress mv_gov40 disproportionality, robust;
regress voters_gov40 disproportionality, robust;
regress relative_congruence40 disproportionality, robust;

regress mv_gov40 disproportionality;
regress voters_gov40 disproportionality;
regress relative_congruence40 disproportionality; 

*     ****************************************************************  *;
*       Robustness checks for Table 2. Results do not depend on whether *;
*       we use all citizens or just the top 40% to estimate party       *;
*       positions.                                                      *;
*     ****************************************************************  *;

regress mv_gov disproportionality, robust cluster(countrycode);
regress voters_gov disproportionality, robust cluster(countrycode);
regress relative_congruence disproportionality, robust cluster(countrycode);

*     ****************************************************************  *;
*       Robustness checks for Table 2. Results do not depend on whether *;
*       we use Achen's measure of relative congruence.                  *;
*     ****************************************************************  *;

regress congruence40_achen disproportionality, robust cluster(countrycode);
regress congruence_achen disproportionality, robust cluster(countrycode);

*     ****************************************************************  *;
*       Robustness checks for Table 2. Results do not depend            *;
*       substantively on whether we use Gallagher's measure of          *;
*       disproportionality or average district magnitude.               *;
*     ****************************************************************  *;

regress mv_gov40 magnitude, robust cluster(countrycode);
regress voters_gov40 magnitude, robust cluster(countrycode);
regress relative_congruence40 magnitude, robust cluster(countrycode);

regress mv_gov magnitude, robust cluster(countrycode);
regress voters_gov magnitude, robust cluster(countrycode);
regress relative_congruence magnitude, robust cluster(countrycode);

*     ****************************************************************  *;
*     ****************************************************************  *;
*       For 2 of the measures, district magnitude has no significant    *;
*       effect on the level of congruence.  However, for relative       *;
*       citizen congruence, there is a negative and significant         *;
*       coefficient indicating that increasing proportionality improves *;
*       congruence. However, the size of this coefficient is so small   *;
*       given the observed range of district magnitude that the         *;
*       substantive effect is effectively 0.  Thus, there is no         *;
*       strong evidence that district magnitude improves congruence.    *;
*     ****************************************************************  *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Robustness checks for Table 2. How stable are the results given *;
*       the somewhat small sample size?  Let's use a jackknife procedure*;
*       to sequentially drop a different observation and see how the    *;
*       coefficient on disproportionality changes.                      *;
*     ****************************************************************  *;

regress mv_gov40 disproportionality, vce(jackknife, mse);
regress voters_gov40 disproportionality, vce(jackknife, mse);
regress relative_congruence40 disproportionality, vce(jackknife, mse);

*     ****************************************************************  *;
*       Coefficients remain negative and stable.                        *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Robustness checks for Table 2. How stable are the results given *;
*       the somewhat small sample size?  Let's use a bootstrap procedure*;
*       to check robustness and obtain corrected standard errors.       *;
*     ****************************************************************  *;

bootstrap, reps(400) seed(10101): regress mv_gov40 disproportionality;
bootstrap, reps(400) seed(10101): regress voters_gov40 disproportionality;
bootstrap, reps(400) seed(10101): regress relative_congruence40 disproportionality;

*     ****************************************************************  *;
*       Coefficients remain negative and stable.                        *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Robustness checks for Table 2. Are any observations exerting    *;
*       a strong effect on the results?                                 *;
*     ****************************************************************  *;

regress mv_gov40 disproportionality;

predict lev, leverage;

sort lev;
list country year lev in -10/l;

drop lev;

*     ****************************************************************  *;
*       A point with leverage greater than (2k+2)/n should be carefully *;
*       examined. Here k is the number of predictors and n is the       *;
*       number of observations. 6/41=0.146. There are three observations*;
*       uk 1997=0.148, uk 2005 = 0.16, and france 2002 = 0.32 with a    *;
*       leverage greater than 0.146.                                    *;
*     ****************************************************************  *;

regress mv_gov40 disproportionality if countrycode~=107, robust cluster(countrycode);   
regress mv_gov40 disproportionality if countrycode~=126, robust cluster(countrycode);   
regress mv_gov40 disproportionality if countrycode~=107 & countrycode~=126, robust cluster(countrycode);   


regress voters_gov40 disproportionality;

predict lev, leverage;

sort lev;
list country year lev in -10/l;

drop lev;

*     ****************************************************************  *;
*       A point with leverage greater than (2k+2)/n should be carefully *;
*       examined. Here k is the number of predictors and n is the       *;
*       number of observations. 6/41=0.146. There are three observations*;
*       uk 1997=0.148, uk 2005 = 0.16, and france 2002 = 0.32 with a    *;
*       leverage greater than 0.146.                                    *;
*     ****************************************************************  *;

regress voters_gov40 disproportionality if countrycode~=107, robust cluster(countrycode);
regress voters_gov40 disproportionality if countrycode~=126, robust cluster(countrycode);
regress voters_gov40 disproportionality if countrycode~=107 & countrycode~=126, robust cluster(countrycode);


regress relative_congruence40 disproportionality;

predict lev, leverage;

sort lev;
list country year lev in -10/l;

*     ****************************************************************  *;
*       A point with leverage greater than (2k+2)/n should be carefully *;
*       examined. Here k is the number of predictors and n is the       *;
*       number of observations. 6/41=0.146. There are three observations*;
*       uk 1997=0.148, uk 2005 = 0.16, and france 2002 = 0.32 with a    *;
*       leverage greater than 0.146.                                    *;
*     ****************************************************************  *;

regress relative_congruence40 disproportionality if countrycode~=107, robust cluster(countrycode);
regress relative_congruence40 disproportionality if countrycode~=126, robust cluster(countrycode); 
regress relative_congruence40 disproportionality if countrycode~=107 & countrycode~=126 , robust cluster(countrycode);

*     ****************************************************************  *;
*       Coefficients remain negative in all but one case and stable.    *;
*     ****************************************************************  *;

*     ****************************************************************  *;
*       Robustness checks for Table 2. The results do not depend on the *;
*       inclusion of countries where the left-right dimensions is not   *;
*       necessarily meaningful.                                         *;
*     ****************************************************************  *;

regress mv_gov40 disproportionality if countrycode~=84, robust cluster(countrycode);   
regress voters_gov40 disproportionality if countrycode~=84, robust cluster(countrycode);
regress relative_congruence40 disproportionality if countrycode~=84, robust cluster(countrycode);

regress mv_gov40 disproportionality if countrycode~=98, robust cluster(countrycode);   
regress voters_gov40 disproportionality if countrycode~=98, robust cluster(countrycode);
regress relative_congruence40 disproportionality if countrycode~=98, robust cluster(countrycode);

regress mv_gov40 disproportionality if countrycode~=103, robust cluster(countrycode);   
regress voters_gov40 disproportionality if countrycode~=103, robust cluster(countrycode);
regress relative_congruence40 disproportionality if countrycode~=103, robust cluster(countrycode); 

regress mv_gov40 disproportionality if countrycode~=111, robust cluster(countrycode);   
regress voters_gov40 disproportionality if countrycode~=111, robust cluster(countrycode);
regress relative_congruence40 disproportionality if countrycode~=111, robust cluster(countrycode);

regress mv_gov40 disproportionality if countrycode~=119, robust cluster(countrycode);   
regress voters_gov40 disproportionality if countrycode~=119, robust cluster(countrycode);
regress relative_congruence40 disproportionality if countrycode~=119, robust cluster(countrycode);

regress mv_gov40 disproportionality if countrycode~=155, robust cluster(countrycode);   
regress voters_gov40 disproportionality if countrycode~=155, robust cluster(countrycode);
regress relative_congruence40 disproportionality if countrycode~=155, robust cluster(countrycode);

regress mv_gov40 disproportionality if countrycode~=176, robust cluster(countrycode);   
regress voters_gov40 disproportionality if countrycode~=176, robust cluster(countrycode);
regress relative_congruence40 disproportionality if countrycode~=176, robust cluster(countrycode);

regress mv_gov40 disproportionality if countrycode~=84 & countrycode~=98 & countrycode~=103 & countrycode~=111 & countrycode~=119 & countrycode~=155 & countrycode~=176, robust cluster(countrycode);   
regress voters_gov40 disproportionality if countrycode~=84 & countrycode~=98 & countrycode~=103 & countrycode~=111 & countrycode~=119 & countrycode~=155 & countrycode~=176, robust cluster(countrycode);
regress relative_congruence40 disproportionality if countrycode~=84 & countrycode~=98 & countrycode~=103 & countrycode~=111 & countrycode~=119 & countrycode~=155 & countrycode~=176, robust cluster(countrycode);

exit;
